@@ -17,14 +17,30 @@ usage:
 :copyright: (c) 2021 by ShengXin Lu.
 '''
 
+from gevent import monkey
+monkey.patch_all()  # 先引用
 from .hooks import lupros
 from .controller import persistence, batch
-from .publictool import original, abnormal
-from .HTTPengine import lupro
+from .HTTPengine import lupro, analyze
 from .api import generator, Batchsubmission, BulkDownload, xpath_Batchanalysis, json_Batchanalysis, re_Batchanalysis, Batchanalysis, async_lupro
 from .__version__ import __title__, __description__, __url__, __version__
 from .__version__ import __author__, __author_email__, __license__
 
+__all__ = [
+   'lupro',    # lupro 控制台 兼容HTTP客服端
+   'lupros',   # lupros 请求参数
+   'batch',    # 批量任务控制器
+   'analyze',  # 解析器
+   'persistence', # 对象持久化控制器
+   'generator', 
+   'Batchsubmission', 
+   'BulkDownload', 
+   'xpath_Batchanalysis', 
+   'json_Batchanalysis', 
+   're_Batchanalysis', 
+   'Batchanalysis', 
+   'async_lupro' # 极简批量请求
+]
 
 '''
 v1.0.4
@@ -39,7 +55,13 @@ v1.0.5
 v1.0.6 v1.0.7
 * 修复了不启用代理且请求错误时的，更新字典的方式
 * 文件结构优化
-* 新增对象持久化
-* 新增批量任务自省，冷重启
+* 新增对象持久化(shelve)
+* 新增批量任务自省，冷重启(atexit)
+
+v1.0.8
+* 改变了 response.encoding 为空时的编码推测(chardet)
+* 优化了html解析器的接口，`response` 类型可直接通过 `class analyze` 和 `class batch` 进行解析
+* 新增 css解析器(parsel)
+* 新增 httpx 客服端(httpx)
 '''
 
