@@ -1,6 +1,6 @@
 '''自定义类型注释'''
 
-from typing import Any
+from typing import Any, Union
 import requests
 
 
